@@ -75,7 +75,7 @@ class BatchSendEmailRequest(AbstractModel):
         :type CycleParam: :class:`tencentcloud.ses.v20201002.models.CycleEmailParam`
         :param TimedParam: 定时发送任务的必要参数
         :type TimedParam: :class:`tencentcloud.ses.v20201002.models.TimedEmailParam`
-        :param Unsubscribe: 退订选项 1: 加入退订链接 0: 不加入退订链接
+        :param Unsubscribe: 退订链接选项 0: 不加入退订链接 1: 简体中文 2: 英文 3: 繁体中文 4: 西班牙语 5: 法语 6: 德语 7: 日语 8: 韩语 9: 阿拉伯语
         :type Unsubscribe: str
         :param ADLocation: 是否添加广告标识 0:不添加 1:添加到subject前面，2:添加到subject后面
         :type ADLocation: int
@@ -1507,13 +1507,17 @@ class SendEmailRequest(AbstractModel):
         :type Subject: str
         :param ReplyToAddresses: 邮件的“回复”电子邮件地址。可以填写您能收到邮件的邮箱地址，可以是个人邮箱。如果不填，收件人的回复邮件将会发送失败。
         :type ReplyToAddresses: str
+        :param Cc: 抄送人邮箱地址，最多支持抄送20人。
+        :type Cc: list of str
+        :param Bcc: 密送人邮箱地址，最多支持抄送20人。
+        :type Bcc: list of str
         :param Template: 使用模板发送时，填写的模板相关参数。因 Simple 已经废除使用，Template 为必填项
         :type Template: :class:`tencentcloud.ses.v20201002.models.Template`
         :param Simple: 已废弃
         :type Simple: :class:`tencentcloud.ses.v20201002.models.Simple`
         :param Attachments: 需要发送附件时，填写附件相关参数。腾讯云接口请求最大支持 8M 的请求包，附件内容经过 Base64 预期扩大1.5倍，应该控制所有附件的总大小最大在 4M 以内，整体请求超出 8M 时接口会返回错误
         :type Attachments: list of Attachment
-        :param Unsubscribe: 退订选项 1: 加入退订链接 0: 不加入退订链接
+        :param Unsubscribe: 退订链接选项 0: 不加入退订链接 1: 简体中文 2: 英文 3: 繁体中文 4: 西班牙语 5: 法语 6: 德语 7: 日语 8: 韩语 9: 阿拉伯语
         :type Unsubscribe: str
         :param TriggerType: 邮件触发类型 0:非触发类，默认类型，营销类邮件、非即时类邮件等选择此类型  1:触发类，验证码等即时发送类邮件，若邮件超过一定大小，系统会自动选择非触发类型通道
         :type TriggerType: int
@@ -1522,6 +1526,8 @@ class SendEmailRequest(AbstractModel):
         self.Destination = None
         self.Subject = None
         self.ReplyToAddresses = None
+        self.Cc = None
+        self.Bcc = None
         self.Template = None
         self.Simple = None
         self.Attachments = None
@@ -1534,6 +1540,8 @@ class SendEmailRequest(AbstractModel):
         self.Destination = params.get("Destination")
         self.Subject = params.get("Subject")
         self.ReplyToAddresses = params.get("ReplyToAddresses")
+        self.Cc = params.get("Cc")
+        self.Bcc = params.get("Bcc")
         if params.get("Template") is not None:
             self.Template = Template()
             self.Template._deserialize(params.get("Template"))
